@@ -1,4 +1,4 @@
-use std::{io::BufRead, path::Path};
+use std::io::BufRead;
 
 use poloto::prelude::*;
 
